@@ -1,19 +1,12 @@
 import httplib2
-from urllib import urlencode
  
-from django.conf import settings
 from django.http import HttpResponse
+
+from httpproxy import settings
+from httpproxy.exceptions import UnkownProxyMode
  
 
-try:
-    PROXY_DOMAIN = getattr(settings, 'PROXY_DOMAIN')
-except AttributeError:
-    from django.core.exceptions import ImproperlyConfigured
-    raise ImproperlyConfigured("To use the 'httpproxy' app, please add the PROXY_DOMAIN setting to your settings file.")
-
-PROXY_PORT = getattr(settings, 'PROXY_PORT', 80)
-
-PROXY_FORMAT = u'http://%s:%d/%s' % (PROXY_DOMAIN, PROXY_PORT, u'%s')
+PROXY_FORMAT = u'http://%s:%d/%s' % (settings.PROXY_DOMAIN, settings.PROXY_PORT, u'%s')
 
 def proxy(request, url):
     conn = httplib2.Http()
@@ -25,12 +18,22 @@ def proxy(request, url):
         pass
     
     if request.method == 'GET':
-        url_ending = '%s?%s' % (url, urlencode(request.GET))
+        url_ending = '%s?%s' % (url, request.GET.urlencode())
         url = PROXY_FORMAT % url_ending
         response, content = conn.request(url, request.method)
     elif request.method == 'POST':
         url = PROXY_FORMAT % url
-        data = urlencode(request.POST)
+        data = request.POST.urlencode()
         response, content = conn.request(url, request.method, data)
     return HttpResponse(content, status=int(response['status']), mimetype=response['content-type'])
+
+
+if settings.PROXY_MODE is not None:
+    proxy_mode = settings.PROXY_MODE
+    try:
+        decorator = getattr(__import__(__package__ + '.decorators', fromlist=proxy_mode), proxy_mode)
+    except AttributeError, e:
+        raise UnkownProxyMode('The proxy mode "%s" could not be found. Please specify a corresponding decorator function in "%s.decorators".' % (proxy_mode, __package__))
+    else:
+        proxy = decorator(proxy)
     
